@@ -12,6 +12,7 @@ from fastapi_users_db_sqlalchemy import (
     SQLAlchemyBaseUserTableUUID,
     SQLAlchemyUserDatabase,
 )
+from tests.conftest import DATABASE_URL
 
 
 def create_async_session_maker(engine: AsyncEngine):
@@ -22,7 +23,7 @@ Base = declarative_base()
 
 
 class User(SQLAlchemyBaseUserTableUUID, Base):
-    first_name = Column(String, nullable=True)
+    first_name = Column(String(255), nullable=True)
 
 
 OAuthBase = declarative_base()
@@ -33,44 +34,38 @@ class OAuthAccount(SQLAlchemyBaseOAuthAccountTableUUID, OAuthBase):
 
 
 class UserOAuth(SQLAlchemyBaseUserTableUUID, OAuthBase):
-    first_name = Column(String, nullable=True)
+    first_name = Column(String(255), nullable=True)
     oauth_accounts: List[OAuthAccount] = relationship("OAuthAccount", lazy="joined")
 
 
 @pytest.fixture
 async def sqlalchemy_user_db() -> AsyncGenerator[SQLAlchemyUserDatabase, None]:
-    DATABASE_URL = "sqlite+aiosqlite:///./test-sqlalchemy-user.db"
-
-    engine = create_async_engine(
-        DATABASE_URL, connect_args={"check_same_thread": False}
-    )
+    engine = create_async_engine(DATABASE_URL)
     sessionmaker = create_async_session_maker(engine)
 
     async with engine.begin() as connection:
         await connection.run_sync(Base.metadata.create_all)
 
-        async with sessionmaker() as session:
-            yield SQLAlchemyUserDatabase(session, User)
+    async with sessionmaker() as session:
+        yield SQLAlchemyUserDatabase(session, User)
 
+    async with engine.begin() as connection:
         await connection.run_sync(Base.metadata.drop_all)
 
 
 @pytest.fixture
 async def sqlalchemy_user_db_oauth() -> AsyncGenerator[SQLAlchemyUserDatabase, None]:
-    DATABASE_URL = "sqlite+aiosqlite:///./test-sqlalchemy-user-oauth.db"
-
-    engine = create_async_engine(
-        DATABASE_URL, connect_args={"check_same_thread": False}
-    )
+    engine = create_async_engine(DATABASE_URL)
     sessionmaker = create_async_session_maker(engine)
 
     async with engine.begin() as connection:
         await connection.run_sync(OAuthBase.metadata.create_all)
 
-        async with sessionmaker() as session:
-            yield SQLAlchemyUserDatabase(session, UserOAuth, OAuthAccount)
+    async with sessionmaker() as session:
+        yield SQLAlchemyUserDatabase(session, UserOAuth, OAuthAccount)
 
-        await connection.run_sync(Base.metadata.drop_all)
+    async with engine.begin() as connection:
+        await connection.run_sync(OAuthBase.metadata.drop_all)
 
 
 @pytest.mark.asyncio
@@ -134,6 +129,7 @@ async def test_insert_existing_email(
         "email": "lancelot@camelot.bt",
         "hashed_password": "guinevere",
     }
+    print("YO")
     await sqlalchemy_user_db.create(user_create)
 
     with pytest.raises(exc.IntegrityError):
